<?php
/*
  $Id: checkout_process.php,v 1.3 2006/02/01 07:11:51 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('EMAIL_TEXT_AUTO_MAIL', '㡡Υ᡼ϼưۿ᡼Ǥ');
define('EMAIL_HONORIFIC', ' ');

define('EMAIL_TEXT_ORDER_NUMBER', 'ʸֹ:');
define('EMAIL_TEXT_INVOICE_URL', 'ʸˤĤƤξ򲼵URLǤˤʤޤ' . "\n");
define('EMAIL_TEXT_DATE_ORDERED', 'ʸ:');
define('EMAIL_TEXT_PRODUCTS', '[ ̾]');
define('EMAIL_TEXT_SUBTITLE', '[]');
define('EMAIL_TEXT_SERIES_TITLE', '[꡼̾]');
define('EMAIL_TEXT_AUTHOR', '[̾]');
define('EMAIL_TEXT_VOLUME', '[]');
define('EMAIL_TEXT_ISBN', '[ISBN]');
define('EMAIL_TEXT_MANUFACTURERS', '[' . KN_CFG_USE_MANUFACTURERS . ']');
define('EMAIL_TEXT_PUBLISHERS', '[Ǹ]');
define('EMAIL_TEXT_PUBLISHED', '[ǯ]');
define('EMAIL_TEXT_DESCRIPTION', '[]');
define('EMAIL_TEXT_MODEL', '[no.]');
define('EMAIL_TEXT_QUANTITY', '[]');
define('EMAIL_TEXT_PRICE', '[]');
define('EMAIL_TEXT_SUBTOTAL', ':');
define('EMAIL_TEXT_TAX', ':');
define('EMAIL_TEXT_SHIPPING', ':');
define('EMAIL_TEXT_TOTAL', '׳:');
define('EMAIL_TEXT_CUSTOMER', '');
define('EMAIL_TEXT_CUSTOMER_NAME', '[̾]');
define('EMAIL_TEXT_CUSTOMER_EMAIL_ADDRESS', '[E-Mailɥ쥹]');
define('EMAIL_TEXT_DELIVERY_ADDRESS', 'Ϥ');
define('EMAIL_TEXT_BILLING_ADDRESS', '');
define('EMAIL_TEXT_PAYMENT_METHOD', 'ʧˡ');
define('EMAIL_TEXT_COMMENT', 'ͤΥ');

define('EMAIL_SEPARATOR', '---------------------------------------------------------------------------');
define('TEXT_EMAIL_VIA', '(ˡ)');
?>